==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ABinopExpression.h <==
// public final class soot.jimple.parser.node.ABinopExpression

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e5d3ef1d80ee8440 soot_jimple_parser_node_ABinopExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_ABinopExpression_H_
#define _JC_soot_jimple_parser_node_ABinopExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PBinopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$sub_refs	_jc_soot_jimple_parser_node_ABinopExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs	_jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$refs	_jc_soot_jimple_parser_node_ABinopExpression$refs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$nonrefs	_jc_soot_jimple_parser_node_ABinopExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$object	_jc_soot_jimple_parser_node_ABinopExpression$object;

typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vmethods	_jc_soot_jimple_parser_node_ABinopExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vtable	_jc_soot_jimple_parser_node_ABinopExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vtype	_jc_soot_jimple_parser_node_ABinopExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$_init$b2186e837e010314(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABinopExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
extern struct _jc_soot_jimple_parser_node_PBinopExpr$object *_jc_soot_jimple_parser_node_ABinopExpression$method$getBinopExpr$064cedbe89393696(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$setBinopExpr$f221fbe5d5c2fb3c(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABinopExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$getBinopExpr$064cedbe89393696;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$setBinopExpr$f221fbe5d5c2fb3c;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABinopExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*(*getBinopExpr$064cedbe89393696)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setBinopExpr$f221fbe5d5c2fb3c)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ABinopExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_ABinopExpression$vmethods	soot_jimple_parser_node_ABinopExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABinopExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABinopExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*__5fbinopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopExpression$refs {
    _jc_soot_jimple_parser_node_ABinopExpression$sub_refs	soot_jimple_parser_node_ABinopExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs	soot_jimple_parser_node_ABinopExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABinopExpression$object {
	_jc_soot_jimple_parser_node_ABinopExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABinopExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABinopExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABinopExpression$vtype _jc_soot_jimple_parser_node_ABinopExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABinopExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABinopExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABinopExpression_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ABinopExpression.h <==
// public final class soot.jimple.parser.node.ABinopExpression

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e5d3ef1d80ee8440 soot_jimple_parser_node_ABinopExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_ABinopExpression_H_
#define _JC_soot_jimple_parser_node_ABinopExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PBinopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$sub_refs	_jc_soot_jimple_parser_node_ABinopExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs	_jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$refs	_jc_soot_jimple_parser_node_ABinopExpression$refs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$nonrefs	_jc_soot_jimple_parser_node_ABinopExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopExpression$object	_jc_soot_jimple_parser_node_ABinopExpression$object;

typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vmethods	_jc_soot_jimple_parser_node_ABinopExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vtable	_jc_soot_jimple_parser_node_ABinopExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABinopExpression$vtype	_jc_soot_jimple_parser_node_ABinopExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$_init$b2186e837e010314(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABinopExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PBinopExpr$object *_jc_soot_jimple_parser_node_ABinopExpression$method$getBinopExpr$064cedbe89393696(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopExpression$method$setBinopExpr$f221fbe5d5c2fb3c(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABinopExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$getBinopExpr$064cedbe89393696;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$setBinopExpr$f221fbe5d5c2fb3c;
extern _jc_method _jc_soot_jimple_parser_node_ABinopExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABinopExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*(*getBinopExpr$064cedbe89393696)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setBinopExpr$f221fbe5d5c2fb3c)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ABinopExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_ABinopExpression$vmethods	soot_jimple_parser_node_ABinopExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABinopExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABinopExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*__5fbinopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopExpression$refs {
    _jc_soot_jimple_parser_node_ABinopExpression$sub_refs	soot_jimple_parser_node_ABinopExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_ABinopExpression$sub_nonrefs	soot_jimple_parser_node_ABinopExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABinopExpression$object {
	_jc_soot_jimple_parser_node_ABinopExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABinopExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABinopExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABinopExpression$vtype _jc_soot_jimple_parser_node_ABinopExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABinopExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABinopExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABinopExpression_H_ */
